============
Installation
============

At the command line::

    $ pip install ceilometer-infoblox

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv ceilometer-infoblox
    $ pip install ceilometer-infoblox